<?php

    namespace FederationLib\Classes;

    class Base32
    {
        /**
         * The base32 alphabet. (RFC 4648)
         *
         * @var string
         */
        private static $alphabet = 'ABCDEFGHIJKLMNOPQRSTUVWXYZ234567';

        /**
         * Encodes a string to base32.
         *
         * @param $string
         * @return string
         */
        public static function encode($string): string
        {
            $binary = '';
            $output = '';
            foreach (str_split($string) as $char)
            {
                $binary .= str_pad(decbin(ord($char)), 8, '0', STR_PAD_LEFT);
            }

            $padding = 5 - (strlen($binary) % 5);

            if ($padding !== 5)
            {
                $binary .= str_repeat('0', $padding);
            }

            $chunks = str_split($binary, 5);
            foreach ($chunks as $chunk)
            {
                $output .= self::$alphabet[bindec($chunk)];
            }

            $padding = (strlen($output) % 8 === 0) ? 0 : (8 - (strlen($output) % 8));
            if ($padding !== 0)
            {
                $output .= str_repeat('=', $padding);
            }

            return $output;
        }

        /**
         * Decodes a base32 encoded string.
         *
         * @param $string
         * @return string
         */
        public static function decode($string): string
        {
            $binary = '';
            $output = '';

            foreach (str_split($string) as $char)
            {
                if ($char === '=')
                    break;
                $binary .= str_pad(decbin(strpos(self::$alphabet, $char)), 5, '0', STR_PAD_LEFT);
            }
            $padding = 8 - (strlen($binary) % 8);

            if ($padding !== 8)
            {
                $binary = substr($binary, 0, -$padding);
            }

            $chunks = str_split($binary, 8);

            foreach ($chunks as $chunk)
            {
                $output .= chr(bindec($chunk));
            }

            return $output;
        }
    }