<?php

    namespace FederationLib\Interfaces;

    use FederationLib\Objects\ClientRecord;
    use FederationLib\Objects\ParsedFederatedAddress;
    use FederationLib\Objects\Standard\PeerMetadata\TelegramUserMetadata;

    interface PeerMetadataManagerInterface
    {
        /**
         * Intelligently syncs the metadata of the given federated address, this will ignore raw metadata & use
         * data from the given $client_uuid
         *
         * @param ClientRecord|string $client_uuid
         * @param PeerMetadataInterface $peer_metadata
         * @return string
         */
        public function syncMetadata(ClientRecord|string $client_uuid, PeerMetadataInterface $peer_metadata): string;

        /**
         * Registers the metadata of the given federated address, this will ignore raw metadata & use data from the
         * given $client_uuid
         *
         * @param ClientRecord|string $client_uuid
         * @param PeerMetadataInterface $peer_metadata
         * @return string
         */
        public function registerMetadata(ClientRecord|string $client_uuid, PeerMetadataInterface $peer_metadata): string;

        /**
         * Returns the metadata of the given federated address, this returns the full raw metadata
         *
         * @param ParsedFederatedAddress|string $federated_address
         * @return PeerMetadataInterface
         */
        public function getMetadata(ParsedFederatedAddress|string $federated_address): PeerMetadataInterface;
    }