<?php

    namespace FederationLib\Objects;

    use FederationLib\Interfaces\SerializableObjectInterface;

    class PeerAssociationRecord implements SerializableObjectInterface
    {
        /**
         * @var string
         */
        private $child_peer;

        /**
         * @var string
         */
        private $parent_peer;

        /**
         * @var string
         */
        private $association_type;

        /**
         * @var string
         */
        private $client_uuid;

        /**
         * @var int
         */
        private $timestamp;

        /**
         * Returns the child peer that is associated with the parent peer.
         *
         * @return string
         */
        public function getChildPeer(): string
        {
            return $this->child_peer;
        }

        /**
         * Returns the parent peer that is associated with the child peer.
         *
         * @return string
         */
        public function getParentPeer(): string
        {
            return $this->parent_peer;
        }

        /**
         * Returns the association type from the child peer to the parent peer.
         *
         * @return string
         */
        public function getAssociationType(): string
        {
            return $this->association_type;
        }

        /**
         * Returns the Client UUID that made this association.
         *
         * @return string
         */
        public function getClientUuid(): string
        {
            return $this->client_uuid;
        }

        /**
         * Returns the Unix Timestamp of when this association was made.
         *
         * @return int
         */
        public function getTimestamp(): int
        {
            return $this->timestamp;
        }

        /**
         * Returns an array representation the object.
         *
         * @return array
         */
        public function toArray(): array
        {
            return [
                'child_peer' => $this->child_peer,
                'parent_peer' => $this->parent_peer,
                'association_type' => $this->association_type,
                'client_uuid' => $this->client_uuid,
                'timestamp' => $this->timestamp
            ];
        }

        /**
         * Constructs object from an array representation
         *
         * @param array $array
         * @return PeerAssociationRecord
         */
        public static function fromArray(array $array): PeerAssociationRecord
        {
            $object = new self();

            $object->child_peer = $array['child_peer'];
            $object->parent_peer = $array['parent_peer'];
            $object->association_type = $array['association_type'];
            $object->client_uuid = $array['client_uuid'];
            $object->timestamp = $array['timestamp'];

            return $object;
        }

    }