<?php

    namespace FederationLib\Objects;

    use FederationLib\Classes\Configuration;
    use FederationLib\Enums\Standard\PermissionRole;
    use FederationLib\Exceptions\Standard\AccessDeniedException;

    class ResolvedIdentity
    {
        /**
         * @var ClientRecord|null
         */
        private $client;

        /**
         * @var ParsedFederatedAddress|null
         */
        private $peer;

        /**
         * @var int
         */
        private $permission_role;

        /**
         * ResolvedIdentity constructor.
         *
         * @param ClientRecord|null $client
         * @param ParsedFederatedAddress|null $peer
         */
        public function __construct(?ClientRecord $client, ?ParsedFederatedAddress $peer=null, bool $allow_root=false)
        {
            $this->client = $client;
            $this->peer = $peer;

            if($this->client === null)
            {
                if(!$allow_root)
                {
                    throw new AccessDeniedException('Missing Client Identity');
                }

                $this->permission_role = PermissionRole::ROOT;
                return;
            }

            if(!Configuration::strictPermissionEnabled())
            {
                if($this->peer === null)
                {
                    $this->permission_role = $this->client->getPermissionRole();
                    return;
                }

                $this->permission_role = $this->peer->getPermissionRole();
                return;
            }

            if($this->peer === null)
            {
                $this->permission_role = $this->client->getPermissionRole();
                return;
            }

            if($this->client->getPermissionRole() > $this->peer->getPermissionRole())
            {
                $this->permission_role = $this->client->getPermissionRole();
                return;
            }

            $this->permission_role = $this->peer->getPermissionRole();
        }

        /**
         * @return ClientRecord|null
         */
        public function getClient(): ?ClientRecord
        {
            return $this->client;
        }

        /**
         * @return ParsedFederatedAddress|null
         */
        public function getPeer(): ?ParsedFederatedAddress
        {
            return $this->peer;
        }

        /**
         * @return int
         */
        public function getPermissionRole(): int
        {
            return $this->permission_role;
        }
    }